package ch.hslu.appe.gui.model;

import java.util.ArrayList;

import javax.swing.table.AbstractTableModel;

import ch.hslu.appe.usermanagement.webservice.AddressDto;
import ch.hslu.appe.webservice.consumer.UserManagementConsumerImpl;

/**
 * Address Table Model.
 */
public class AddressTableModel extends AbstractTableModel {

    private static final long serialVersionUID = 1L;
    private final String[] tableHeader;
    private Object[][] tableData;
    private ArrayList<AddressDto> addresses;

    /**
     * Constructor.
     */
    public AddressTableModel() {

        tableHeader = new String[] {"Id", "Strasse", "PLZ", "Ort", "Typ" };

        generateTableData(1);
    }

    /**
     * Gets the column class.
     * @param c colum
     * @return column class
     */
    @SuppressWarnings({ "unchecked", "rawtypes" })
    @Override
    public final Class getColumnClass(final int c) {
        return getValueAt(0, c).getClass();
    }

    /**
     * Gets the number of columns.
     * @return number of columns
     */
    @Override
    public final int getColumnCount() {
        return tableHeader.length;
    }

    /**
     * Gets the name of the column.
     * @param col column
     * @return name of the column
     */
    @Override
    public final String getColumnName(final int col) {
        return tableHeader[col];
    }

    /**
     * Gets the number of rows.
     * @return number of rows
     */
    @Override
    public final int getRowCount() {
        return tableData.length;
    }

    /**
     * Gets the Table Entry.
     * @param row row
     * @param col col
     * @return entry
     */
    @Override
    public final Object getValueAt(final int row, final int col) {
        return tableData[row][col];
    }

    @Override
    public final void setValueAt(final Object value, final int row, final int col) {
        tableData[row][col] = value;
        fireTableCellUpdated(row, col);
    }

    /**
     * Generate / Update Table Data.
     * @param userId userId
     */
    public final void generateTableData(final int userId) {

        addresses = UserManagementConsumerImpl.getInstance().getAddressesById(userId);

        if (addresses == null) {
            return;
        }

        tableData = new Object[addresses.size()][5];

        String addrType;
        for (int index = 0; index < addresses.size(); index++) {
            AddressDto address = addresses.get(index);

            switch (address.getType()) {
            case 0:
                addrType = "Lieferadresse";
                break;
            default:
                addrType = "Rechnunsadresse";
                break;
            }

            tableData[index][0] = address.getId();
            tableData[index][1] = address.getStreet();
            tableData[index][2] = address.getZipCode();
            tableData[index][3] = address.getPlace();
            tableData[index][4] = addrType;
        }
    }
}
