package ch.hslu.appe.webservice.consumer;

import java.util.ArrayList;

import ch.hslu.appe.order.webservice.IllegalNameException_Exception;
import ch.hslu.appe.order.webservice.OrderDto;
import ch.hslu.appe.order.webservice.OrderException_Exception;
import ch.hslu.appe.order.webservice.OrderNotExistsException_Exception;
import ch.hslu.appe.order.webservice.OrderState;
import ch.hslu.appe.order.webservice.SOAPException_Exception;

/**
 * OrderConsumer.
 */
public interface OrderConsumer {

    /**
     * addPosition.
     * @param orderNumber orderNumber
     * @param productNumber productNumber
     * @param amount amount
     * @return successfully
     * @throws OrderException_Exception OrderException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    int addPosition(int orderNumber, int productNumber, int amount) throws OrderException_Exception,
            SOAPException_Exception;

    /**
     * annulateOrder.
     * @param number number
     * @return successfully
     * @throws OrderException_Exception OrderException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    boolean annulateOrder(int number) throws OrderException_Exception, SOAPException_Exception;

    /**
     * createOrder.
     * @param order order
     * @return successfully
     * @throws OrderException_Exception OrderException_Exception
     * @throws IllegalNameException_Exception IllegalNameException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    int createOrder(OrderDto order) throws OrderException_Exception, IllegalNameException_Exception,
            SOAPException_Exception;

    /**
     * deletePosition.
     * @param orderNumber orderNumber
     * @param positionNumber positionNumber
     * @return successfully
     * @throws OrderException_Exception OrderException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    boolean deletePosition(int orderNumber, int positionNumber) throws OrderException_Exception,
            SOAPException_Exception;

    /**
     * getActiveOrder.
     * @return ActiveOrder
     * @throws SOAPException_Exception SOAPException_Exception
     */
    OrderDto getActiveOrder() throws SOAPException_Exception;

    /**
     * getOrder.
     * @param number number
     * @return Order
     * @throws OrderException_Exception OrderException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    OrderDto getOrder(int number) throws OrderException_Exception, SOAPException_Exception;

    /**
     * getOrders.
     * @return OrderDto ArrayList
     */
    ArrayList<OrderDto> getOrders();

    /**
     * getStatus.
     * @param orderNumber orderNumber
     * @return OrderState
     * @throws OrderNotExistsException_Exception OrderNotExistsException_Exception
     */
    OrderState getStatus(int orderNumber) throws OrderNotExistsException_Exception;

    /**
     * releaseOrder.
     * @param orderNumber orderNumber
     * @throws OrderException_Exception OrderException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    void releaseOrder(int orderNumber) throws OrderException_Exception, SOAPException_Exception;

    /**
     * setStatus.
     * @param orderNumber orderNumber
     * @param state state
     * @return successfully
     * @throws OrderException_Exception OrderException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    boolean setStatus(int orderNumber, OrderState state) throws OrderException_Exception, SOAPException_Exception;

    /**
     * submitOrder.
     * @param number number
     * @return successfully
     * @throws OrderException_Exception OrderException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    boolean submitOrder(int number) throws OrderException_Exception, SOAPException_Exception;

    /**
     * updateOrder.
     * @param order order
     * @return successfully
     * @throws OrderException_Exception OrderException_Exception
     * @throws IllegalNameException_Exception IllegalNameException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    boolean updateOrder(OrderDto order) throws OrderException_Exception, IllegalNameException_Exception,
            SOAPException_Exception;

    /**
     * updatePosition.
     * @param orderNumber orderNumber
     * @param positionNumber positionNumber
     * @param amount amount
     * @return successfully
     * @throws OrderException_Exception OrderException_Exception
     * @throws SOAPException_Exception SOAPException_Exception
     */
    boolean updatePosition(int orderNumber, int positionNumber, int amount) throws OrderException_Exception,
            SOAPException_Exception;
}
