package ch.hslu.appe.webservice.consumer;

import java.util.ArrayList;

import ch.hslu.appe.order.webservice.IllegalNameException_Exception;
import ch.hslu.appe.order.webservice.OrderDto;
import ch.hslu.appe.order.webservice.OrderException_Exception;
import ch.hslu.appe.order.webservice.OrderNotExistsException_Exception;
import ch.hslu.appe.order.webservice.OrderService;
import ch.hslu.appe.order.webservice.OrderServiceImplService;
import ch.hslu.appe.order.webservice.OrderState;
import ch.hslu.appe.order.webservice.SOAPException_Exception;

/**
 * OrderConsumerImpl.
 */
public final class OrderConsumerImpl implements OrderConsumer {

    private final OrderService orderService;
    private static OrderConsumerImpl instance;

    /**
     * getInstance.
     * @return instance
     */
    public static OrderConsumer getInstance() {

        if (instance == null) {
            instance = new OrderConsumerImpl();
        }

        return instance;
    }

    /**
     * OrderConsumerImpl.
     */
    private OrderConsumerImpl() {
        orderService = (new OrderServiceImplService()).getOrderServiceImplPort();
    }

    @Override
    public int addPosition(final int orderNumber, final int productNumber, final int amount)
            throws OrderException_Exception, SOAPException_Exception {
        return orderService.addPosition(orderNumber, productNumber, amount);
    }

    @Override
    public boolean annulateOrder(final int number) throws OrderException_Exception, SOAPException_Exception {
        return orderService.annulateOrder(number);
    }

    @Override
    public int createOrder(final OrderDto order) throws OrderException_Exception, IllegalNameException_Exception,
            SOAPException_Exception {
        return orderService.createOrder(order);
    }

    @Override
    public boolean deletePosition(final int orderNumber, final int positionNumber) throws OrderException_Exception,
            SOAPException_Exception {
        return orderService.deletePosition(orderNumber, positionNumber);
    }

    @Override
    public OrderDto getActiveOrder() throws SOAPException_Exception {
        return orderService.getActiveOrder();
    }

    @Override
    public OrderDto getOrder(final int number) throws OrderException_Exception, SOAPException_Exception {
        return orderService.getOrder(number);
    }

    @Override
    public ArrayList<OrderDto> getOrders() {
        return (ArrayList<OrderDto>) orderService.getOrders();
    }

    @Override
    public OrderState getStatus(final int orderNumber) throws OrderNotExistsException_Exception {
        return orderService.getStatus(orderNumber);
    }

    @Override
    public void releaseOrder(final int orderNumber) throws OrderException_Exception, SOAPException_Exception {
        orderService.releaseOrder(orderNumber);

    }

    @Override
    public boolean setStatus(final int orderNumber, final OrderState state) throws OrderException_Exception,
            SOAPException_Exception {
        return orderService.setStatus(orderNumber, state);
    }

    @Override
    public boolean submitOrder(final int number) throws OrderException_Exception, SOAPException_Exception {
        return orderService.submitOrder(number);
    }

    @Override
    public boolean updateOrder(final OrderDto order) throws OrderException_Exception, IllegalNameException_Exception,
            SOAPException_Exception {
        return orderService.updateOrder(order);
    }

    @Override
    public boolean updatePosition(final int orderNumber, final int positionNumber, final int amount)
            throws OrderException_Exception, SOAPException_Exception {
        return orderService.updatePosition(orderNumber, positionNumber, amount);
    }

}
