package ch.hslu.appe.webservice.consumer;

import java.util.ArrayList;

import ch.hslu.appe.usermanagement.webservice.AddressDto;
import ch.hslu.appe.usermanagement.webservice.IllegalNameException_Exception;
import ch.hslu.appe.usermanagement.webservice.UserDto;
import ch.hslu.appe.usermanagement.webservice.UserManagementService;
import ch.hslu.appe.usermanagement.webservice.UserManagementServiceImplService;

/**
 * UserManagementConsumerImpl.
 */
public final class UserManagementConsumerImpl implements UserManagementConsumer {

    private final UserManagementService userManagementService;
    private static UserManagementConsumerImpl instance;

    /**
     * getInstance.
     * @return instance
     */
    public static UserManagementConsumer getInstance() {

        if (instance == null) {
            instance = new UserManagementConsumerImpl();
        }

        return instance;
    }

    /**
     * Private constructor.
     */
    private UserManagementConsumerImpl() {
        userManagementService = (new UserManagementServiceImplService()).getUserManagementServiceImplPort();
    }

    @Override
    public boolean addAddress(final int userId, final AddressDto address) {

        return userManagementService.addAddress(userId, address);
    }

    @Override
    public boolean addUser(final UserDto user) throws IllegalNameException_Exception {

        return userManagementService.addUser(user);
    }

    @Override
    public boolean deleteAddress(final int addressId) {

        return userManagementService.deleteAddress(addressId);
    }

    @Override
    public boolean deleteUser(final int userId) {

        return userManagementService.deleteUser(userId);
    }

    @Override
    public AddressDto getAddress(final int addressId) {

        return userManagementService.getAddress(addressId);
    }

    @Override
    public ArrayList<AddressDto> getAddressesById(final int userId) {

        return (ArrayList<AddressDto>) userManagementService.getAddressesById(userId);
    }

    @Override
    public ArrayList<AddressDto> getAddressesByLogin(final String login) {

        return (ArrayList<AddressDto>) userManagementService.getAddressesByLogin(login);
    }

    @Override
    public UserDto getUserById(final int userId) {

        return userManagementService.getUserById(userId);
    }

    @Override
    public UserDto getUserByLogin(final String login) {

        return userManagementService.getUserByLogin(login);
    }

    @Override
    public ArrayList<UserDto> getUsers() {

        return (ArrayList<UserDto>) userManagementService.getUsers();
    }

    @Override
    public boolean updateAddress(final AddressDto address) {

        return userManagementService.updateAddress(address);
    }

    @Override
    public boolean updateUser(final UserDto user) throws IllegalNameException_Exception {

        return userManagementService.updateUser(user);
    }

}
